# Tutorials

The current tutorials stay close to the implemented codebase.

- [1. First Kernel](01-first-kernel.md) boots a local kernel and inspects its channels.
- [2. Expose Public Channels](02-expose-public-channels.md) explains how to run AAAX with HTTP transport for selected public channels.
